@@ -136,6 +136,7 @@ struct mail_storage {
 	   MAIL_FETCH_IMAP_BODYSTRUCTURE from the remote server. Adding fields
 	   here avoids adding them to index_mail_data.access_part. */
 	enum mail_fetch_field nonbody_access_fields;
+	struct event_category *event_category;
 
         struct mail_storage_vfuncs v, *vlast;
 
@@ -233,14 +234,16 @@ struct mailbox_vfuncs {
 	int (*set_subscribed)(struct mailbox *box, bool set);
 
 	int (*attribute_set)(struct mailbox_transaction_context *t,
-			     enum mail_attribute_type type, const char *key,
+			     enum mail_attribute_type type_flags,
+			     const char *key,
 			     const struct mail_attribute_value *value);
 	int (*attribute_get)(struct mailbox *box,
-			     enum mail_attribute_type type, const char *key,
+			     enum mail_attribute_type type_flags,
+			     const char *key,
 			     struct mail_attribute_value *value_r);
 	struct mailbox_attribute_iter *
 		(*attribute_iter_init)(struct mailbox *box,
-				       enum mail_attribute_type type,
+				       enum mail_attribute_type type_flags,
 				       const char *prefix);
 	const char *(*attribute_iter_next)(struct mailbox_attribute_iter *iter);
 	int (*attribute_iter_deinit)(struct mailbox_attribute_iter *iter);
@@ -555,6 +558,8 @@ struct mail_private {
 	const char *get_stream_reason;
 
 	bool autoexpunged:1;
+	/* mail created by mailbox_search_*() */
+	bool search_mail:1;
 };
 
 struct mailbox_list_context {
@@ -650,6 +655,10 @@ struct mail_search_context {
 	uint32_t seq;
 	uint32_t progress_cur, progress_max;
 
+	ARRAY(struct mail *) mails;
+	unsigned int unused_mail_idx;
+	unsigned int max_mails;
+
 	ARRAY(union mail_search_module_context *) module_contexts;
 
 	bool seen_lost_data:1;
@@ -667,7 +676,7 @@ struct mail_save_data {
 
 	uint32_t uid, stub_seq;
 	char *guid, *pop3_uidl, *from_envelope;
-	unsigned int pop3_order;
+	uint32_t pop3_order;
 
 	struct ostream *output;
 	struct mail_save_attachment *attach;
@@ -842,4 +851,7 @@ enum mail_index_open_flags
 mail_storage_settings_to_index_flags(const struct mail_storage_settings *set);
 void mailbox_save_context_deinit(struct mail_save_context *ctx);
 
+/* for unit testing */
+int mailbox_verify_name(struct mailbox *box);
+
 #endif
